@@ -365,6 +365,9 @@
 "      <xsd:element name=\"center\" type=\"docMarkupType\" />\n"
 "      <xsd:element name=\"small\" type=\"docMarkupType\" />\n"
 "      <xsd:element name=\"htmlonly\" type=\"xsd:string\" />\n"
+"      <xsd:element name=\"manonly\" type=\"xsd:string\" />\n"
+"      <xsd:element name=\"xmlonly\" type=\"xsd:string\" />\n"
+"      <xsd:element name=\"rtfonly\" type=\"xsd:string\" />\n"
 "      <xsd:element name=\"latexonly\" type=\"xsd:string\" />\n"
 "      <xsd:element name=\"dot\" type=\"xsd:string\" />\n"
 "      <xsd:element name=\"anchor\" type=\"docAnchorType\" />\n"
@@ -419,6 +422,7 @@
 "      <xsd:element name=\"parameterlist\" type=\"docParamListType\" />\n"
 "      <xsd:element name=\"xrefsect\" type=\"docXRefSectType\" />\n"
 "      <xsd:element name=\"copydoc\" type=\"docCopyType\" />\n"
+"      <xsd:element name=\"blockquote\" type=\"docBlockQuoteType\" />\n"
 "    </xsd:choice>\n"
 "  </xsd:group>\n"
 "\n"
@@ -612,6 +616,12 @@
 "    <xsd:attribute name=\"link\" type=\"xsd:string\" /> \n"
 "  </xsd:complexType>\n"
 "\n"
+"  <xsd:complexType name=\"docBlockQuoteType\">\n"
+"    <xsd:sequence>\n"
+"      <xsd:element name=\"para\" type=\"docParaType\" minOccurs=\"0\" maxOccurs=\"unbounded\" />\n"
+"    </xsd:sequence>\n"
+"  </xsd:complexType>\n"
+"\n"
 "  <xsd:complexType name=\"docCharType\">\n"
 "    <xsd:attribute name=\"char\" type=\"DoxCharRange\"/> \n"
 "  </xsd:complexType>\n"
@@ -764,6 +774,7 @@
 "      <xsd:enumeration value=\"warning\" />\n"
 "      <xsd:enumeration value=\"pre\" />\n"
 "      <xsd:enumeration value=\"post\" />\n"
+"      <xsd:enumeration value=\"copyright\" />\n"
 "      <xsd:enumeration value=\"invariant\" />\n"
 "      <xsd:enumeration value=\"remark\" />\n"
 "      <xsd:enumeration value=\"attention\" />\n"
@@ -814,6 +825,8 @@
 "      <xsd:enumeration value=\"retain\"/>\n"
 "      <xsd:enumeration value=\"copy\"/>\n"
 "      <xsd:enumeration value=\"assign\"/>\n"
+"      <xsd:enumeration value=\"weak\"/>\n"
+"      <xsd:enumeration value=\"strong\"/>\n"
 "    </xsd:restriction>\n"
 "  </xsd:simpleType>\n"
 "\n"
