@@ -3,7 +3,7 @@
  * $Id: def.cpp,v 1.2 2001/01/01 10:15:18 root Exp $
  *
  *
- * Copyright (C) 1997-2010 by Dimitri van Heesch.
+ * Copyright (C) 1997-2012 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -28,6 +28,7 @@
 #include "defargs.h"
 #include "outputgen.h"
 #include "dot.h"
+#include "arguments.h"
 
 #include <qdir.h>
 #include <qfile.h>
@@ -35,7 +36,7 @@
 
 #define DEF_DB(x)
 
-inline void writeDEFString(QTextStream &t,const char *s)
+inline void writeDEFString(FTextStream &t,const char *s)
 {
   const char* p=s;
   char c;
@@ -51,7 +52,7 @@ inline void writeDEFString(QTextStream &t,const char *s)
 }
 
 void generateDEFForMember(MemberDef *md,
-    QTextStream &t,
+    FTextStream &t,
     Definition *def,
     const char* Prefix)
 {
@@ -312,7 +313,7 @@ void generateDEFForMember(MemberDef *md,
 
 
 void generateDEFClassSection(ClassDef *cd,
-    QTextStream &t,
+    FTextStream &t,
     MemberList *ml,
     const char *kind)
 {
@@ -331,7 +332,7 @@ void generateDEFClassSection(ClassDef *cd,
   }
 }
 
-void generateDEFForClass(ClassDef *cd,QTextStream &t)
+void generateDEFForClass(ClassDef *cd,FTextStream &t)
 {
   // + brief description
   // + detailed description
@@ -474,7 +475,7 @@ void generateDEFForClass(ClassDef *cd,QTextStream &t)
 }
 
 void generateDEFSection(Definition *d,
-    QTextStream &t,
+    FTextStream &t,
     MemberList *ml,
     const char *kind)
 {
@@ -491,7 +492,7 @@ void generateDEFSection(Definition *d,
   }
 }
 
-void generateDEFForNamespace(NamespaceDef *nd,QTextStream &t)
+void generateDEFForNamespace(NamespaceDef *nd,FTextStream &t)
 {
   if (nd->isReference()) return; // skip external references
   t << "  namespace = {" << endl;
@@ -517,7 +518,7 @@ void generateDEFForNamespace(NamespaceDef *nd,QTextStream &t)
   t << "  };" << endl;
 }
 
-void generateDEFForFile(FileDef *fd,QTextStream &t)
+void generateDEFForFile(FileDef *fd,FTextStream &t)
 {
   if (fd->isReference()) return; // skip external references
 
@@ -552,7 +553,7 @@ void generateDEF()
   QCString outputDirectory = Config_getString("OUTPUT_DIRECTORY");
   if (outputDirectory.isEmpty())
   {
-    outputDirectory=QDir::currentDirPath();
+    outputDirectory=QDir::currentDirPath().utf8();
   }
   else
   {
@@ -562,18 +563,18 @@ void generateDEF()
       dir.setPath(QDir::currentDirPath());
       if (!dir.mkdir(outputDirectory))
       {
-        err("Error: tag OUTPUT_DIRECTORY: Output directory `%s' does not "
+        err("error: tag OUTPUT_DIRECTORY: Output directory `%s' does not "
             "exist and cannot be created\n",outputDirectory.data());
         exit(1);
       }
       else if (!Config_getBool("QUIET"))
       {
-        err("Notice: Output directory `%s' does not exist. "
+        err("notice: Output directory `%s' does not exist. "
             "I have created it for you.\n", outputDirectory.data());
       }
       dir.cd(outputDirectory);
     }
-    outputDirectory=dir.absPath();
+    outputDirectory=dir.absPath().utf8();
   }
 
   QDir dir(outputDirectory);
@@ -600,7 +601,7 @@ void generateDEF()
     err("Cannot open file %s for writing!\n",fileName.data());
     return;
   }
-  QTextStream t(&f);
+  FTextStream t(&f);
   t << "AutoGen Definitions dummy;" << endl;
 
   if (Doxygen::classSDict->count()+Doxygen::inputNameList->count()>0)
