@@ -1,6 +1,6 @@
 /******************************************************************************
  *
- * Copyright (C) 1997-2010 by Dimitri van Heesch.
+ * Copyright (C) 1997-2012 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -13,12 +13,11 @@
  *
  */
 
+#include <qfile.h>
 #include "docsets.h"
 #include "config.h"
 #include "message.h"
 #include "doxygen.h"
-#include <qfile.h>
-
 
 DocSets::DocSets() : m_nodes(17), m_scopes(17)
 {
@@ -135,7 +134,8 @@ void DocSets::initialize()
     err("Could not open file %s for writing\n",notes.data());
     exit(1);
   }
-  QCString indexName=Config_getBool("GENERATE_TREEVIEW")?"main":"index";
+  //QCString indexName=Config_getBool("GENERATE_TREEVIEW")?"main":"index";
+  QCString indexName="index";
   m_nts.setDevice(m_nf);
   m_nts << "<?xml version=\"1.0\" encoding=\"UTF-8\"?>" << endl;
   m_nts << "<DocSetNodes version=\"1.0\">" << endl;
@@ -162,7 +162,10 @@ void DocSets::initialize()
 
 void DocSets::finalize()
 {
-  m_nts << indent() << " </Node>" << endl;
+  if (!m_firstNode.at(m_dc-1))
+  {
+    m_nts << indent() << " </Node>" << endl;
+  }
   m_dc--;
   m_nts << "      </Subnodes>" << endl;
   m_nts << "    </Node>" << endl;
@@ -210,7 +213,10 @@ void DocSets::addContentsItem(bool isDir,
                               const char *name, 
                               const char *ref, 
                               const char *file,
-                              const char *anchor)
+                              const char *anchor,
+                              bool /* separateIndex */,
+                              bool /* addToNavIndex */,
+                              Definition * /*def*/)
 {
   (void)isDir;
   if (file && ref==0)
@@ -222,7 +228,9 @@ void DocSets::addContentsItem(bool isDir,
     m_firstNode.at(m_dc-1)=FALSE;
     m_nts << indent() << " <Node>" << endl;
     m_nts << indent() << "  <Name>" << convertToXML(name) << "</Name>" << endl;
-    m_nts << indent() << "  <Path>" << file << Doxygen::htmlFileExtension << "</Path>" << endl;
+    m_nts << indent() << "  <Path>";
+    m_nts << file << Doxygen::htmlFileExtension;
+    m_nts << "</Path>" << endl;
     if (anchor)
     {
       m_nts << indent() << "  <Anchor>" << anchor << "</Anchor>" << endl;
@@ -253,7 +261,14 @@ void DocSets::addIndexItem(Definition *context,MemberDef *md,const char *)
   // determine language
   QCString lang;
   SrcLangExt langExt = SrcLangExt_Cpp;
-  if (fd) langExt = getLanguageFromFileName(fd->name());
+  if (md) 
+  {
+    langExt = md->getLanguage();
+  }
+  else if (context) 
+  {
+    langExt = context->getLanguage();
+  }
   switch (langExt)
   {
     case SrcLangExt_Cpp:
@@ -276,10 +291,12 @@ void DocSets::addIndexItem(Definition *context,MemberDef *md,const char *)
     case SrcLangExt_Java:    lang="java"; break;       // Java
     case SrcLangExt_JS:      lang="javascript"; break; // Javascript
     case SrcLangExt_Python:  lang="python"; break;     // Python
-    case SrcLangExt_F90:     lang="fortran"; break;    // Fortran
+    case SrcLangExt_Fortran: lang="fortran"; break;    // Fortran
     case SrcLangExt_VHDL:    lang="vhdl"; break;       // VHDL
     case SrcLangExt_XML:     lang="xml"; break;        // DBUS XML
-    case SrcLangExt_Unknown: lang="unknown"; break;   // should not happen!
+    case SrcLangExt_Tcl:     lang="tcl"; break;        // Tcl
+    case SrcLangExt_Markdown:lang="markdown"; break;   // Markdown
+    case SrcLangExt_Unknown: lang="unknown"; break;    // should not happen!
   }
 
   if (md)
@@ -430,7 +447,7 @@ void DocSets::writeToken(FTextStream &t,
 {
   t << "  <Token>" << endl;
   t << "    <TokenIdentifier>" << endl;
-  QString name = d->name();
+  QCString name = d->name();
   if (name.right(2)=="-p")  name=name.left(name.length()-2);
   t << "      <Name>" << convertToXML(name) << "</Name>" << endl;
   if (!lang.isEmpty())
