@@ -3,7 +3,7 @@
  * $Id: dot.h,v 1.14 2001/03/19 19:27:40 root Exp $
  *
  *
- * Copyright (C) 1997-2010 by Dimitri van Heesch.
+ * Copyright (C) 1997-2012 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -42,7 +42,7 @@ class DotRunnerQueue;
 
 enum GraphOutputFormat { BITMAP , EPS };
 
-/** @brief Attributes of an edge of a dot graph */
+/** Attributes of an edge of a dot graph */
 struct EdgeInfo
 {
   enum Colors { Blue=0, Green=1, Red=2, Purple=3, Grey=4, Orange=5 };
@@ -56,7 +56,7 @@ struct EdgeInfo
   int m_labColor;
 };
 
-/** @brief A node in a dot graph */
+/** A node in a dot graph */
 class DotNode
 {
   public:
@@ -138,7 +138,7 @@ inline int DotNode::findParent( DotNode *n )
     return m_parents->find(n);
 }
 
-/** @brief Represents a graphical class hierarchy */
+/** Represents a graphical class hierarchy */
 class DotGfxHierarchyTable
 {
   public:
@@ -156,7 +156,7 @@ class DotGfxHierarchyTable
     DotNodeList    *m_rootSubgraphs;
 };
 
-/** @brief Representation of a class inheritance or dependency graph */
+/** Representation of a class inheritance or dependency graph */
 class DotClassGraph
 {
   public:
@@ -166,7 +166,7 @@ class DotClassGraph
     bool isTooBig() const;
     QCString writeGraph(FTextStream &t,GraphOutputFormat f,const char *path,
                     const char *fileName, const char *relPath, 
-                    bool TBRank=TRUE,bool imageMap=TRUE) const;
+                    bool TBRank=TRUE,bool imageMap=TRUE,int graphId=-1) const;
 
     void writeXML(FTextStream &t);
     void writeDEF(FTextStream &t);
@@ -188,7 +188,7 @@ class DotClassGraph
     bool               m_lrRank;
 };
 
-/** @brief Representation of an include dependency graph */
+/** Representation of an include dependency graph */
 class DotInclDepGraph
 {
   public:
@@ -196,7 +196,7 @@ class DotInclDepGraph
    ~DotInclDepGraph();
     QCString writeGraph(FTextStream &t, GraphOutputFormat f,
                     const char *path,const char *fileName,const char *relPath,
-                    bool writeImageMap=TRUE) const;
+                    bool writeImageMap=TRUE,int graphId=-1) const;
     bool isTrivial() const;
     bool isTooBig() const;
     QCString diskName() const;
@@ -215,7 +215,7 @@ class DotInclDepGraph
     bool            m_inverse;
 };
 
-/** @brief Representation of an call graph */
+/** Representation of an call graph */
 class DotCallGraph
 {
   public:
@@ -223,7 +223,8 @@ class DotCallGraph
    ~DotCallGraph();
     QCString writeGraph(FTextStream &t, GraphOutputFormat f,
                         const char *path,const char *fileName,
-                        const char *relPath,bool writeImageMap=TRUE) const;
+                        const char *relPath,bool writeImageMap=TRUE,
+                        int graphId=-1) const;
     void buildGraph(DotNode *n,MemberDef *md,int distance);
     bool isTrivial() const;
     bool isTooBig() const;
@@ -241,7 +242,7 @@ class DotCallGraph
     Definition *    m_scope;
 };
 
-/** @brief Representation of an directory dependency graph */
+/** Representation of an directory dependency graph */
 class DotDirDeps
 {
   public:
@@ -253,12 +254,13 @@ class DotDirDeps
                         const char *path,
                         const char *fileName,
                         const char *relPath,
-                        bool writeImageMap=TRUE) const;
+                        bool writeImageMap=TRUE,
+                        int graphId=-1) const;
   private:
     DirDef *m_dir;
 };
 
-/** @brief Representation of a group collaboration graph */
+/** Representation of a group collaboration graph */
 class DotGroupCollaboration
 {
   public :
@@ -299,7 +301,7 @@ class DotGroupCollaboration
     ~DotGroupCollaboration();
     QCString writeGraph(FTextStream &t, GraphOutputFormat format,
                     const char *path,const char *fileName,const char *relPath,
-                    bool writeImageMap=TRUE) const;
+                    bool writeImageMap=TRUE,int graphId=-1) const;
     void buildGraph(GroupDef* gd);
     bool isTrivial() const;
   private :
@@ -316,7 +318,7 @@ class DotGroupCollaboration
     QList<Edge>     m_edges;
 };
 
-/** @brief Helper class to run dot from doxygen.
+/** Helper class to run dot from doxygen.
  */
 class DotRunner
 {
@@ -356,7 +358,7 @@ class DotRunner
     CleanupItem m_cleanupItem;
 };
 
-/** @brief Helper class to insert a set of map file into an output file */
+/** Helper class to insert a set of map file into an output file */
 class DotFilePatcher
 {
   public:
@@ -367,22 +369,27 @@ class DotFilePatcher
       bool     urlOnly;
       QCString context;
       QCString label;
+      bool     zoomable;
+      int      graphId;
     };
     DotFilePatcher(const char *patchFile);
     int addMap(const QCString &mapFile,const QCString &relPath,
                bool urlOnly,const QCString &context,const QCString &label);
     int addFigure(const QCString &baseName,
                   const QCString &figureName,bool heightCheck);
-    int addSVGConversion(const QCString &relPath,bool urlOnly,const QCString &context);
+    int addSVGConversion(const QCString &relPath,bool urlOnly,
+                         const QCString &context,bool zoomable,int graphId);
     int addSVGObject(const QCString &baseName, const QCString &figureName,
                      const QCString &relPath);
     bool run();
+    QCString file() const;
 
   private:
     QList<Map> m_maps;
     QCString m_patchFile;
 };
 
+/** Queue of dot jobs to run. */
 class DotRunnerQueue
 {
   public:
@@ -395,6 +402,7 @@ class DotRunnerQueue
     mutable QMutex  m_mutex;
 };
 
+/** Worker thread to execute a dot run */
 class DotWorkerThread : public QThread
 {
   public:
@@ -407,7 +415,7 @@ class DotWorkerThread : public QThread
     QList<DotRunner::CleanupItem> m_cleanupItems;
 };
 
-/** @brief singleton that manages dot relation actions */
+/** Singleton that manages dot relation actions */
 class DotManager
 {
   public:
@@ -419,7 +427,7 @@ class DotManager
     int addFigure(const QCString &file,const QCString &baseName,
                   const QCString &figureName,bool heightCheck);
     int addSVGConversion(const QCString &file,const QCString &relPath,
-               bool urlOnly,const QCString &context);
+               bool urlOnly,const QCString &context,bool zoomable,int graphId);
     int addSVGObject(const QCString &file,const QCString &baseName,
                      const QCString &figureNAme,const QCString &relPath);
     bool run();
@@ -442,7 +450,8 @@ void writeDotGraphFromFile(const char *inFile,const char *outDir,
                            const char *outFile,GraphOutputFormat format);
 void writeDotImageMapFromFile(FTextStream &t,
                               const QCString& inFile, const QCString& outDir,
-                              const QCString& relPath,const QCString& context);
+                              const QCString& relPath,const QCString& baseName,
+                              const QCString& context,int graphId=-1);
 
 void writeDotDirDepGraph(FTextStream &t,DirDef *dd);
 
