@@ -1,6 +1,6 @@
 /******************************************************************************
  *
- * Copyright (C) 1997-2010 by Dimitri van Heesch.
+ * Copyright (C) 1997-2012 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -155,13 +155,19 @@ void EclipseHelp::decContentsDepth()
  * @param ref URL of the item
  * @param file Name of a file which the item is defined in (without extension)
  * @param anchor Name of an anchor of the item.
+ * @param separateIndex not used.
+ * @param addToNavIndex not used.
+ * @param def not used.
  */
 void EclipseHelp::addContentsItem(
     bool /* isDir */,
     const char *name,
     const char * /* ref */,
     const char *file,
-    const char *anchor) 
+    const char *anchor,
+    bool /* separateIndex */,
+    bool /* addToNavIndex */,
+    Definition * /*def*/) 
 {
   // -- write the topic tag 
   closedTag();
