@@ -1,7 +1,7 @@
 /******************************************************************************
  * 
  *
- * Copyright (C) 1997-2010 by Dimitri van Heesch.
+ * Copyright (C) 1997-2012 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -206,14 +206,14 @@ void FormulaList::generateBitmaps(const char *path)
         QTextStream t(&f);
         QCString s;
         if (!t.eof())
-          s=t.readLine();
+          s=t.readLine().utf8();
         if (s.length()<2 || s.left(2)!="P6")
           err("error: ghostscript produced an illegal image format!");
         else
         {
-          // assume the size if after the first line that does not start with
+          // assume the size is after the first line that does not start with
           // # excluding the first line of the file.
-          while (!t.eof() && (s=t.readLine()) && !s.isEmpty() && s.at(0)=='#') { }
+          while (!t.eof() && (s=t.readLine().utf8()) && !s.isEmpty() && s.at(0)=='#') { }
           sscanf(s,"%d %d",&imageX,&imageY);
         }
         if (imageX>0 && imageY>0)
