@@ -3,7 +3,7 @@
  * $Id: layout.h,v 1.2 2001/03/19 19:27:41 root Exp $
  *
  *
- * Copyright (C) 1997-2010 by Dimitri van Heesch.
+ * Copyright (C) 1997-2012 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -38,21 +38,23 @@ struct LayoutDocEntry
               AuthorSection,
               
               // Class specific items
-              ClassIncludes,
+              ClassIncludes, ClassInlineClasses,
               ClassInheritanceGraph, ClassNestedClasses,
               ClassCollaborationGraph, ClassAllMembersLink,
               ClassUsedFiles,
 
               // Namespace specific items
               NamespaceNestedNamespaces, NamespaceClasses,
+              NamespaceInlineClasses,
 
               // File specific items
               FileClasses, FileNamespaces, 
               FileIncludes, FileIncludeGraph, 
               FileIncludedByGraph, FileSourceLink,
+              FileInlineClasses,
 
               // Group specific items
-              GroupClasses, GroupNamespaces,
+              GroupClasses, GroupInlineClasses, GroupNamespaces,
               GroupDirs, GroupNestedGroups, GroupFiles,
               GroupGraph, GroupPageDocs,
 
@@ -113,15 +115,20 @@ struct LayoutNavEntry
       Pages,
       Modules, 
       Namespaces, 
+      NamespaceList,
       NamespaceMembers,
-      Classes, 
-      ClassAnnotated, 
+      Classes,
+      ClassList, 
+      ClassIndex, 
       ClassHierarchy, 
       ClassMembers,
       Files, 
+      FileList,
       FileGlobals,
-      Dirs, 
-      Examples
+      //Dirs, 
+      Examples,
+      User,
+      UserGroup
     };
     LayoutNavEntry(LayoutNavEntry *parent,Kind k,bool vs,const QCString &bf, 
                    const QCString &tl,const QCString &intro,bool prepend=FALSE) 
@@ -134,12 +141,13 @@ struct LayoutNavEntry
     QCString baseFile() const        { return m_baseFile; }
     QCString title() const           { return m_title; }
     QCString intro() const           { return m_intro; }
+    QCString url() const;
     bool visible()                   { return m_visible; }
     void clear()                     { m_children.clear(); }
     void addChild(LayoutNavEntry *e) { m_children.append(e); }
     void prependChild(LayoutNavEntry *e) { m_children.prepend(e); }
     const QList<LayoutNavEntry> &children() const { return m_children; }
-    LayoutNavEntry *find(LayoutNavEntry::Kind k) const;
+    LayoutNavEntry *find(LayoutNavEntry::Kind k,const char *file=0) const;
 
   private:
     LayoutNavEntry() : m_parent(0) {}
@@ -173,7 +181,7 @@ class LayoutDocManager
     LayoutNavEntry *rootNavEntry() const;
 
     /** Parses a user provided layout */
-    void parse(QTextStream &t);
+    void parse(QTextStream &t,const char *fileName);
     void init();
   private:
     void addEntry(LayoutPart p,LayoutDocEntry*e);
