@@ -1038,8 +1038,8 @@ in the Decoder's interface in the C++ version.
 
 getBpp():          bits per pixel of the PNG image
 getChannels():     amount of color channels of the PNG image
-isGreyscaleType(): it's color type 0 or 4
-isAlphaType():     it's color type 2 or 6
+isGreyscaleType(): its color type 0 or 4
+isAlphaType():     its color type 2 or 6
 
 These values are calculated out of color type and bit depth of InfoColor.
 
@@ -1120,7 +1120,7 @@ The meanings of the LodePNG error values:
 *) 53: size of zlib data too small
 *) 55: jumped past tree while generating huffman tree, this could be when the
        tree will have more leaves than symbols after generating it out of the
-       given lenghts. They call this an oversubscribed dynamic bit lengths tree in zlib.
+       given lengths. They call this an oversubscribed dynamic bit lengths tree in zlib.
 *) 56: given output image colorType or bitDepth not supported for color conversion
 *) 57: invalid CRC encountered (checking CRC can be disabled)
 *) 58: invalid ADLER32 encountered (checking ADLER32 can be disabled)
