@@ -3,7 +3,7 @@
  *
  *
  *
- * Copyright (C) 1997-2010 by Dimitri van Heesch.
+ * Copyright (C) 1997-2012 by Dimitri van Heesch.
  * Authors: Dimitri van Heesch, Miguel Lobo.
  *
  * Permission to use, copy, modify, and distribute this software and its
@@ -30,6 +30,7 @@
 #include <qdict.h>
 #include <qfile.h>
 #include "ftextstream.h"
+#include "arguments.h"
 
 #define PERLOUTPUT_MAX_INDENTATION 40
 
@@ -297,6 +298,7 @@ public:
   void visit(DocFormula *);
   void visit(DocIndexEntry *);
   void visit(DocSimpleSectSep *);
+  void visit(DocCite *);
 
   //--------------------------------------
   // visitor functions for compound nodes
@@ -374,6 +376,8 @@ public:
   void visitPost(DocCopy *);
   void visitPre(DocText *);
   void visitPost(DocText *);
+  void visitPre(DocHtmlBlockQuote *);
+  void visitPost(DocHtmlBlockQuote *);
 
 private:
 
@@ -636,6 +640,7 @@ void PerlModDocVisitor::visit(DocVerbatim *s)
     return;
   case DocVerbatim::Verbatim:	type = "preformatted"; break;
   case DocVerbatim::HtmlOnly:	type = "htmlonly"; break;
+  case DocVerbatim::RtfOnly:	type = "rtfonly"; break;
   case DocVerbatim::ManOnly:	type = "manonly"; break;
   case DocVerbatim::LatexOnly:	type = "latexonly"; break;
   case DocVerbatim::XmlOnly:	type = "xmlonly"; break;
@@ -682,6 +687,7 @@ void PerlModDocVisitor::visit(DocInclude *inc)
   case DocInclude::DontInclude:	return;
   case DocInclude::HtmlInclude:	type = "htmlonly"; break;
   case DocInclude::VerbInclude:	type = "preformatted"; break;
+  case DocInclude::Snippet: return;
   }
   openItem(type);
   m_output.addFieldQuotedString("content", inc->text());
@@ -737,6 +743,14 @@ void PerlModDocVisitor::visit(DocSimpleSectSep *)
 {
 }
 
+void PerlModDocVisitor::visit(DocCite *cite)
+{
+  openItem("cite");
+  m_output.addFieldQuotedString("text", cite->text());
+  closeItem();
+}
+
+
 //--------------------------------------
 // visitor functions for compound nodes
 //--------------------------------------
@@ -808,6 +822,7 @@ void PerlModDocVisitor::visitPre(DocSimpleSect *s)
   case DocSimpleSect::Warning:		type = "warning"; break;
   case DocSimpleSect::Pre:		type = "pre"; break;
   case DocSimpleSect::Post:		type = "post"; break;
+  case DocSimpleSect::Copyright:	type = "copyright"; break;
   case DocSimpleSect::Invar:		type = "invariant"; break;
   case DocSimpleSect::Remark:		type = "remark"; break;
   case DocSimpleSect::Attention:	type = "attention"; break;
@@ -1107,7 +1122,7 @@ void PerlModDocVisitor::visitPre(DocMscFile *)
 void PerlModDocVisitor::visitPost(DocMscFile *)
 {
 #if 0
-  m_output.add("</dotfile>");
+  m_output.add("<mscfile>");
 #endif
 }
 
@@ -1289,6 +1304,18 @@ void PerlModDocVisitor::visitPost(DocText *)
 {
 }
 
+void PerlModDocVisitor::visitPre(DocHtmlBlockQuote *)
+{
+  openItem("blockquote");
+  openSubBlock("content");
+}
+
+void PerlModDocVisitor::visitPost(DocHtmlBlockQuote *)
+{
+  closeSubBlock();
+  closeItem();
+}
+
 static void addTemplateArgumentList(ArgumentList *al,PerlModOutput &output,const char *)
 {
   QCString indentStr;
@@ -1379,7 +1406,7 @@ static QCString pathDoxyExec;
 void setPerlModDoxyfile(const QCString &qs)
 {
   pathDoxyfile = qs;
-  pathDoxyExec = QDir::currentDirPath();
+  pathDoxyExec = QDir::currentDirPath().utf8();
 }
 
 class PerlModGenerator
@@ -1531,6 +1558,11 @@ void PerlModGenerator::generatePerlModForMember(MemberDef *md,Definition *)
     }
     m_output.closeList();
   }
+  else if (md->argsString()!=0) 
+  {
+    m_output.addFieldQuotedString("arguments", md->argsString());
+  }
+
   if (!md->initializer().isEmpty())
     m_output.addFieldQuotedString("initializer", md->initializer());
   
@@ -1692,7 +1724,7 @@ void PerlModGenerator::generatePerlModForClass(ClassDef *cd)
     m_output.closeList();
   }
 
-  ClassSDict *cl = cd->getInnerClasses();
+  ClassSDict *cl = cd->getClassSDict();
   if (cl)
   {
     m_output.openList("inner");
@@ -2125,7 +2157,7 @@ bool PerlModGenerator::createOutputDir(QDir &perlModDir)
   QCString outputDirectory = Config_getString("OUTPUT_DIRECTORY");
   if (outputDirectory.isEmpty())
   {
-    outputDirectory=QDir::currentDirPath();
+    outputDirectory=QDir::currentDirPath().utf8();
   }
   else
   {
@@ -2146,7 +2178,7 @@ bool PerlModGenerator::createOutputDir(QDir &perlModDir)
       }
       dir.cd(outputDirectory);
     }
-    outputDirectory=dir.absPath();
+    outputDirectory=dir.absPath().utf8();
   }
 
   QDir dir(outputDirectory);
@@ -2839,20 +2871,21 @@ void PerlModGenerator::generate()
 
   bool perlmodLatex = Config_getBool("PERLMOD_LATEX");
 
-  pathDoxyDocsPM = perlModDir.absPath() + "/DoxyDocs.pm";
-  pathDoxyStructurePM = perlModDir.absPath() + "/DoxyStructure.pm";
-  pathMakefile = perlModDir.absPath() + "/Makefile";
-  pathDoxyRules = perlModDir.absPath() + "/doxyrules.make";
+  QCString perlModAbsPath = perlModDir.absPath().utf8();
+  pathDoxyDocsPM = perlModAbsPath + "/DoxyDocs.pm";
+  pathDoxyStructurePM = perlModAbsPath + "/DoxyStructure.pm";
+  pathMakefile = perlModAbsPath + "/Makefile";
+  pathDoxyRules = perlModAbsPath + "/doxyrules.make";
 
   if (perlmodLatex) {
-    pathDoxyStructureTex = perlModDir.absPath() + "/doxystructure.tex";
-    pathDoxyFormatTex = perlModDir.absPath() + "/doxyformat.tex";
-    pathDoxyLatexTex = perlModDir.absPath() + "/doxylatex.tex";
-    pathDoxyLatexDVI = perlModDir.absPath() + "/doxylatex.dvi";
-    pathDoxyLatexPDF = perlModDir.absPath() + "/doxylatex.pdf";
-    pathDoxyDocsTex = perlModDir.absPath() + "/doxydocs.tex";
-    pathDoxyLatexPL = perlModDir.absPath() + "/doxylatex.pl";
-    pathDoxyLatexStructurePL = perlModDir.absPath() + "/doxylatex-structure.pl";
+    pathDoxyStructureTex = perlModAbsPath + "/doxystructure.tex";
+    pathDoxyFormatTex = perlModAbsPath + "/doxyformat.tex";
+    pathDoxyLatexTex = perlModAbsPath + "/doxylatex.tex";
+    pathDoxyLatexDVI = perlModAbsPath + "/doxylatex.dvi";
+    pathDoxyLatexPDF = perlModAbsPath + "/doxylatex.pdf";
+    pathDoxyDocsTex = perlModAbsPath + "/doxydocs.tex";
+    pathDoxyLatexPL = perlModAbsPath + "/doxylatex.pl";
+    pathDoxyLatexStructurePL = perlModAbsPath + "/doxylatex-structure.pl";
   }
 
   if (!(generatePerlModOutput()
