@@ -33,6 +33,7 @@ static QCString makeFileName(const char * withoutExtension)
 
 static QCString makeRef(const char * withoutExtension, const char * anchor)
 {
+  //printf("QHP::makeRef(%s,%s)\n",withoutExtension,anchor);
   if (!withoutExtension) return QCString(); 
   QCString result = makeFileName(withoutExtension);
   if (!anchor) return result;
@@ -85,10 +86,10 @@ void Qhp::initialize()
     { "name", filterName, 0 };
     m_doc.open("customFilter", tagAttributes);
 
-    QStringList customFilterAttributes = QStringList::split(' ', Config_getString("QHP_CUST_FILTER_ATTRS"));
+    QStringList customFilterAttributes = QStringList::split(QChar(' '), Config_getString("QHP_CUST_FILTER_ATTRS"));
     for (int i = 0; i < (int)customFilterAttributes.count(); i++)
     {
-      m_doc.openCloseContent("filterAttribute", customFilterAttributes[i]);
+      m_doc.openCloseContent("filterAttribute", customFilterAttributes[i].utf8());
     }
     m_doc.close("customFilter");
   }
@@ -96,7 +97,7 @@ void Qhp::initialize()
   m_doc.open("filterSection");
 
   // Add section attributes
-  QStringList sectionFilterAttributes = QStringList::split(' ',
+  QStringList sectionFilterAttributes = QStringList::split(QChar(' '),
       Config_getString("QHP_SECT_FILTER_ATTRS"));
   if (!sectionFilterAttributes.contains(QString("doxygen")))
   {
@@ -104,7 +105,7 @@ void Qhp::initialize()
   }
   for (int i = 0; i < (int)sectionFilterAttributes.count(); i++)
   {
-    m_doc.openCloseContent("filterAttribute", sectionFilterAttributes[i]);
+    m_doc.openCloseContent("filterAttribute", sectionFilterAttributes[i].utf8());
   }
 
   m_toc.open("toc");
@@ -172,7 +173,9 @@ void Qhp::decContentsDepth()
 
 void Qhp::addContentsItem(bool /*isDir*/, const char * name, 
                           const char * /*ref*/, const char * file, 
-                          const char * /*anchor*/)
+                          const char * /*anchor*/,bool /* separateIndex */,
+                          bool /* addToNavIndex */,
+                          Definition * /*def*/)
 {
   // Backup difference before modification
   int diff = m_prevSectionLevel - m_sectionLevel;
@@ -191,6 +194,10 @@ void Qhp::addIndexItem(Definition *context,MemberDef *md,
                        const char *word)
 {
   (void)word;
+  //printf("addIndexItem(%s %s %s\n",
+  //       context?context->name().data():"<none>",
+  //       md?md->name().data():"<none>",
+  //       word);
 
   if (md) // member
   {
