@@ -3,7 +3,7 @@
  * $Id: $
  *
  *
- * Copyright (C) 1997-2010 by Dimitri van Heesch.
+ * Copyright (C) 1997-2012 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -34,6 +34,24 @@
 //#define DBG_RTF(x) m_t << x
 #define DBG_RTF(x) do {} while(0)
 
+static QCString align(DocHtmlCell *cell)
+{
+  HtmlAttribList attrs = cell->attribs();
+  uint i;
+  for (i=0; i<attrs.count(); ++i) 
+  {
+    if (attrs.at(i)->name.lower()=="align")
+    {
+      if (attrs.at(i)->value.lower()=="center") 
+        return "\\qc ";
+      else if (attrs.at(i)->value.lower()=="right") 
+        return "\\qr ";
+      else return "";
+    }
+  }
+  return "";
+}
+
 RTFDocVisitor::RTFDocVisitor(FTextStream &t,CodeOutputInterface &ci,
                              const char *langExt) 
   : DocVisitor(DocVisitor_RTF), m_t(t), m_ci(ci), m_insidePre(FALSE), 
@@ -328,13 +346,18 @@ void RTFDocVisitor::visit(DocVerbatim *s)
 {
   if (m_hide) return;
   DBG_RTF("{\\comment RTFDocVisitor::visit(DocVerbatim)}\n");
+  QCString lang = m_langExt;
+  if (!s->language().isEmpty()) // explicit language setting
+  {
+    lang = s->language();
+  }
   switch(s->type())
   {
     case DocVerbatim::Code: // fall though
       m_t << "{" << endl;
       m_t << "\\par" << endl;
       m_t << rtf_Style_Reset << getStyle("CodeExample");
-      Doxygen::parserManager->getParser(m_langExt)
+      Doxygen::parserManager->getParser(lang)
                             ->parseCode(m_ci,s->context(),s->text(),
                                         s->isExample(),s->exampleFile());
       //m_t << "\\par" << endl; 
@@ -348,6 +371,9 @@ void RTFDocVisitor::visit(DocVerbatim *s)
       //m_t << "\\par" << endl; 
       m_t << "}" << endl;
       break;
+    case DocVerbatim::RtfOnly: 
+      m_t << s->text(); 
+      break;
     case DocVerbatim::HtmlOnly: 
     case DocVerbatim::LatexOnly: 
     case DocVerbatim::XmlOnly: 
@@ -434,13 +460,13 @@ void RTFDocVisitor::visit(DocInclude *inc)
   DBG_RTF("{\\comment RTFDocVisitor::visit(DocInclude)}\n");
   switch(inc->type())
   {
-   case DocInclude::IncWithLines:
+     case DocInclude::IncWithLines:
       { 
          m_t << "{" << endl;
          m_t << "\\par" << endl;
          m_t << rtf_Style_Reset << getStyle("CodeExample");
          QFileInfo cfi( inc->file() );
-         FileDef fd( cfi.dirPath(), cfi.fileName() );
+         FileDef fd( cfi.dirPath().utf8(), cfi.fileName().utf8() );
          Doxygen::parserManager->getParser(inc->extension())
                                ->parseCode(m_ci,inc->context(),
                                            inc->text(),
@@ -450,7 +476,7 @@ void RTFDocVisitor::visit(DocInclude *inc)
          m_t << "}" << endl;
       }
       break;
-   case DocInclude::Include: 
+    case DocInclude::Include: 
       m_t << "{" << endl;
       m_t << "\\par" << endl;
       m_t << rtf_Style_Reset << getStyle("CodeExample");
@@ -473,6 +499,19 @@ void RTFDocVisitor::visit(DocInclude *inc)
       m_t << "\\par";
       m_t << "}" << endl;
       break;
+    case DocInclude::Snippet:
+      m_t << "{" << endl;
+      if (!m_lastIsPara) m_t << "\\par" << endl;
+      m_t << rtf_Style_Reset << getStyle("CodeExample");
+      Doxygen::parserManager->getParser(inc->extension())
+                            ->parseCode(m_ci,
+                                        inc->context(),
+                                        extractBlock(inc->text(),inc->blockId()),
+                                        inc->isExample(),
+                                        inc->exampleFile()
+                                       );
+      m_t << "}";
+      break;
   }
   m_lastIsPara=TRUE;
 }
@@ -543,6 +582,30 @@ void RTFDocVisitor::visit(DocSimpleSectSep *)
 {
 }
 
+void RTFDocVisitor::visit(DocCite *cite)
+{
+  if (m_hide) return;
+  DBG_RTF("{\\comment RTFDocVisitor::visitPre(DocCite)}\n");
+  if (!cite->file().isEmpty()) 
+  {
+    startLink(cite->ref(),cite->file(),cite->anchor());
+  }
+  else
+  {
+    m_t << "{\\b ";
+  }
+  filter(cite->text());
+  if (!cite->file().isEmpty()) 
+  {
+    endLink(cite->ref());
+  }
+  else
+  {
+    m_t << "}";
+  }
+}
+
+
 //--------------------------------------
 // visitor functions for compound nodes
 //--------------------------------------
@@ -663,6 +726,8 @@ void RTFDocVisitor::visitPre(DocSimpleSect *s)
       m_t << theTranslator->trPrecondition(); break;
     case DocSimpleSect::Post:
       m_t << theTranslator->trPostcondition(); break;
+    case DocSimpleSect::Copyright:
+      m_t << theTranslator->trCopyright(); break;
     case DocSimpleSect::Invar:
       m_t << theTranslator->trInvariant(); break;
     case DocSimpleSect::Remark:
@@ -750,6 +815,8 @@ void RTFDocVisitor::visitPre(DocSection *s)
   if (m_hide) return;
   DBG_RTF("{\\comment RTFDocVisitor::visitPre(DocSection)}\n");
   if (!m_lastIsPara) m_t << "\\par" << endl;
+  m_t << "{\\bkmkstart " << rtfFormatBmkStr(s->file()+"_"+s->anchor()) << "}" << endl;
+  m_t << "{\\bkmkend " << rtfFormatBmkStr(s->file()+"_"+s->anchor()) << "}" << endl;
   m_t << "{{" // start section
       << rtf_Style_Reset;
   QCString heading;
@@ -885,7 +952,8 @@ void RTFDocVisitor::visitPost(DocHtmlTable *)
 {
   if (m_hide) return;
   DBG_RTF("{\\comment RTFDocVisitor::visitPost(DocHtmlTable)}\n");
-  m_t << "\\pard" << endl;
+  m_t << "\\pard\\plain" << endl;
+  m_t << "\\par" << endl;
   m_lastIsPara=TRUE;
 }
 
@@ -913,6 +981,10 @@ void RTFDocVisitor::visitPre(DocHtmlRow *r)
          "\\trbrdrv\\brdrs\\brdrw10 "<< endl;
   for (i=0;i<r->numCells();i++)
   {
+    if (r->isHeading())
+    {
+      m_t << "\\clcbpat16"; // set cell shading to light grey (color 16 in the clut)
+    }
     m_t << "\\clvertalt\\clbrdrt\\brdrs\\brdrw10 "
            "\\clbrdrl\\brdrs\\brdrw10 "
            "\\clbrdrb\\brdrs\\brdrw10 "
@@ -934,11 +1006,11 @@ void RTFDocVisitor::visitPost(DocHtmlRow *)
   m_lastIsPara=FALSE;
 }
 
-void RTFDocVisitor::visitPre(DocHtmlCell *)
+void RTFDocVisitor::visitPre(DocHtmlCell *c)
 {
   if (m_hide) return;
   DBG_RTF("{\\comment RTFDocVisitor::visitPre(DocHtmlCell)}\n");
-  m_t << "{";
+  m_t << "{" << align(c);
   m_lastIsPara=FALSE;
 }
 
@@ -953,25 +1025,25 @@ void RTFDocVisitor::visitPost(DocHtmlCell *)
 void RTFDocVisitor::visitPre(DocInternal *)
 {
   if (m_hide) return;
-  DBG_RTF("{\\comment RTFDocVisitor::visitPre(DocInternal)}\n");
-  m_t << "{"; // start desc
-  m_t << "{\\b "; // start bold
-  m_t << theTranslator->trForInternalUseOnly();
-  m_t << "}"; // end bold
-  m_t << "\\par" << endl;
-  incIndentLevel();
-  m_t << rtf_Style_Reset << getStyle("DescContinue");
-  m_lastIsPara=FALSE;
+  //DBG_RTF("{\\comment RTFDocVisitor::visitPre(DocInternal)}\n");
+  //m_t << "{"; // start desc
+  //m_t << "{\\b "; // start bold
+  //m_t << theTranslator->trForInternalUseOnly();
+  //m_t << "}"; // end bold
+  //m_t << "\\par" << endl;
+  //incIndentLevel();
+  //m_t << rtf_Style_Reset << getStyle("DescContinue");
+  //m_lastIsPara=FALSE;
 }
 
 void RTFDocVisitor::visitPost(DocInternal *) 
 {
   if (m_hide) return;
-  DBG_RTF("{\\comment RTFDocVisitor::visitPost(DocInternal)}\n");
-  m_t << "\\par";
-  decIndentLevel();
-  m_t << "}"; // end desc
-  m_lastIsPara=TRUE;
+  //DBG_RTF("{\\comment RTFDocVisitor::visitPost(DocInternal)}\n");
+  //m_t << "\\par";
+  //decIndentLevel();
+  //m_t << "}"; // end desc
+  //m_lastIsPara=TRUE;
 }
 
 void RTFDocVisitor::visitPre(DocHRef *href)
@@ -1084,7 +1156,7 @@ void RTFDocVisitor::visitPost(DocDotFile *)
 }
 void RTFDocVisitor::visitPre(DocMscFile *df)
 {
-  DBG_RTF("{\\comment RTFDocVisitor::visitPre(MscDotFile)}\n");
+  DBG_RTF("{\\comment RTFDocVisitor::visitPre(DocMscFile)}\n");
   writeMscFile(df->file());
 
   // hide caption since it is not supported at the moment
@@ -1094,7 +1166,7 @@ void RTFDocVisitor::visitPre(DocMscFile *df)
 
 void RTFDocVisitor::visitPost(DocMscFile *) 
 {
-  DBG_RTF("{\\comment RTFDocVisitor::visitPost(MscDotFile)}\n");
+  DBG_RTF("{\\comment RTFDocVisitor::visitPost(DocMscFile)}\n");
   popEnabled();
 }
 
@@ -1116,7 +1188,16 @@ void RTFDocVisitor::visitPre(DocRef *ref)
 {
   if (m_hide) return;
   DBG_RTF("{\\comment RTFDocVisitor::visitPre(DocRef)}\n");
-  if (!ref->file().isEmpty()) startLink(ref->ref(),ref->file(),ref->anchor());
+  // when ref->isSubPage()==TRUE we use ref->file() for HTML and
+  // ref->anchor() for LaTeX/RTF
+  if (ref->isSubPage())
+  {
+    startLink(ref->ref(),0,ref->anchor());
+  }
+  else
+  {
+    if (!ref->file().isEmpty()) startLink(ref->ref(),ref->file(),ref->anchor());
+  }
   if (!ref->hasLinkText()) filter(ref->targetTitle());
 }
 
@@ -1125,7 +1206,7 @@ void RTFDocVisitor::visitPost(DocRef *ref)
   if (m_hide) return;
   DBG_RTF("{\\comment RTFDocVisitor::visitPost(DocRef)}\n");
   if (!ref->file().isEmpty()) endLink(ref->ref());
-  m_t << " ";
+  //m_t << " ";
 }
 
 
@@ -1242,7 +1323,7 @@ void RTFDocVisitor::visitPre(DocParamList *pl)
   { { 2, 25, 100, 100, 100 }, // no inout, no type
     { 3, 14,  35, 100, 100 }, // inout, no type
     { 3, 25,  50, 100, 100 }, // no inout, type
-    { 4, 14,  35, 55,  100 }, // no inout, type
+    { 4, 14,  35, 55,  100 }, // inout, type
   };
   int config=0;
   if (m_hide) return;
@@ -1379,11 +1460,11 @@ void RTFDocVisitor::visitPost(DocParamList *pl)
   DBG_RTF("{\\comment RTFDocVisitor::visitPost(DocParamList)}\n");
 
   DocParamSect::Type parentType = DocParamSect::Unknown;
-  DocParamSect *sect = 0;
+  //DocParamSect *sect = 0;
   if (pl->parent() && pl->parent()->kind()==DocNode::Kind_ParamSect)
   {
     parentType = ((DocParamSect*)pl->parent())->type();
-    sect=(DocParamSect*)pl->parent();
+    //sect=(DocParamSect*)pl->parent();
   }
   bool useTable = parentType==DocParamSect::Param ||
                   parentType==DocParamSect::RetVal ||
@@ -1478,24 +1559,49 @@ void RTFDocVisitor::visitPost(DocInternalRef *)
 
 void RTFDocVisitor::visitPre(DocCopy *)
 {
+  if (m_hide) return;
   DBG_RTF("{\\comment RTFDocVisitor::visitPre(DocCopy)}\n");
 }
 
 void RTFDocVisitor::visitPost(DocCopy *)
 {
+  if (m_hide) return;
   DBG_RTF("{\\comment RTFDocVisitor::visitPost(DocCopy)}\n");
 }
 
 void RTFDocVisitor::visitPre(DocText *)
 {
+  if (m_hide) return;
   DBG_RTF("{\\comment RTFDocVisitor::visitPre(DocText)}\n");
 }
 
 void RTFDocVisitor::visitPost(DocText *)
 {
+  if (m_hide) return;
   DBG_RTF("{\\comment RTFDocVisitor::visitPost(DocText)}\n");
 }
 
+void RTFDocVisitor::visitPre(DocHtmlBlockQuote *)
+{
+  if (m_hide) return;
+  DBG_RTF("{\\comment RTFDocVisitor::visitPre(DocHtmlBlockQuote)}\n");
+  if (!m_lastIsPara) m_t << "\\par" << endl;
+  m_t << "{"; // start desc
+  incIndentLevel();
+  m_t << rtf_Style_Reset << getStyle("DescContinue"); 
+}
+
+void RTFDocVisitor::visitPost(DocHtmlBlockQuote *)
+{
+  if (m_hide) return;
+  DBG_RTF("{\\comment RTFDocVisitor::visitPost(DocHtmlBlockQuote)}\n");
+  if (!m_lastIsPara) m_t << "\\par" << endl;
+  decIndentLevel();
+  m_t << "}"; // end desc
+  m_lastIsPara=TRUE;
+}
+
+
 //static char* getMultiByte(int c)
 //{
 //    static char s[10];
@@ -1558,9 +1664,12 @@ void RTFDocVisitor::startLink(const QCString &ref,const QCString &file,const QCS
     {
       refName+=file;
     }
-    if (anchor)
+    if (!file.isEmpty() && anchor)
     {
       refName+='_';
+    }
+    if (anchor)
+    {
       refName+=anchor;
     }
 
@@ -1631,7 +1740,7 @@ void RTFDocVisitor::writeMscFile(const QCString &fileName)
     baseName=baseName.right(baseName.length()-i-1);
   } 
   QCString outDir = Config_getString("RTF_OUTPUT");
-  writeMscGraphFromFile(fileName,outDir,baseName,MSC_BITMAP);
+  writeMscGraphFromFile(fileName+".msc",outDir,baseName,MSC_BITMAP);
   if (!m_lastIsPara) m_t << "\\par" << endl;
   m_t << "{" << endl;
   m_t << rtf_Style_Reset;
