@@ -3,7 +3,7 @@
  * $Id: $
  *
  *
- * Copyright (C) 1997-2010 by Dimitri van Heesch.
+ * Copyright (C) 1997-2012 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -194,6 +194,11 @@ void XmlDocVisitor::visit(DocVerbatim *s)
       filter(s->text());
       m_t << "</htmlonly>";
       break;
+    case DocVerbatim::RtfOnly: 
+      m_t << "<rtfonly>";
+      filter(s->text());
+      m_t << "</rtfonly>";
+      break;
     case DocVerbatim::ManOnly: 
       m_t << "<manonly>";
       filter(s->text());
@@ -235,7 +240,7 @@ void XmlDocVisitor::visit(DocInclude *inc)
       { 
          m_t << "<programlisting>";
          QFileInfo cfi( inc->file() );
-         FileDef fd( cfi.dirPath(), cfi.fileName() );
+         FileDef fd( cfi.dirPath().utf8(), cfi.fileName().utf8() );
          Doxygen::parserManager->getParser(inc->extension())
                                ->parseCode(m_ci,inc->context(),
                                            inc->text(),
@@ -265,6 +270,17 @@ void XmlDocVisitor::visit(DocInclude *inc)
       filter(inc->text());
       m_t << "</verbatim>"; 
       break;
+    case DocInclude::Snippet:
+      m_t << "<programlisting>";
+      Doxygen::parserManager->getParser(inc->extension())
+                            ->parseCode(m_ci,
+                                        inc->context(),
+                                        extractBlock(inc->text(),inc->blockId()),
+                                        inc->isExample(),
+                                        inc->exampleFile()
+                                       );
+      m_t << "</programlisting>"; 
+      break;
   }
 }
 
@@ -329,6 +345,14 @@ void XmlDocVisitor::visit(DocSimpleSectSep *)
   m_t << "<simplesectsep/>";
 }
 
+void XmlDocVisitor::visit(DocCite *cite)
+{
+  if (m_hide) return;
+  if (!cite->file().isEmpty()) startLink(cite->ref(),cite->file(),cite->anchor());
+  filter(cite->text());
+  if (!cite->file().isEmpty()) endLink();
+}
+
 //--------------------------------------
 // visitor functions for compound nodes
 //--------------------------------------
@@ -421,6 +445,8 @@ void XmlDocVisitor::visitPre(DocSimpleSect *s)
       m_t << "pre"; break;
     case DocSimpleSect::Post:
       m_t << "post"; break;
+    case DocSimpleSect::Copyright:
+      m_t << "copyright"; break;
     case DocSimpleSect::Invar:
       m_t << "invariant"; break;
     case DocSimpleSect::Remark:
@@ -564,7 +590,7 @@ void XmlDocVisitor::visitPre(DocHtmlTable *t)
 {
   if (m_hide) return;
   m_t << "<table rows=\"" << t->numRows() 
-      << "\" cols=\"" << t->numCols() << "\">" ;
+      << "\" cols=\"" << t->numColumns() << "\">" ;
 }
 
 void XmlDocVisitor::visitPost(DocHtmlTable *) 
@@ -721,7 +747,7 @@ void XmlDocVisitor::visitPre(DocMscFile *df)
 void XmlDocVisitor::visitPost(DocMscFile *) 
 {
   if (m_hide) return;
-  m_t << "</dotfile>" << endl;
+  m_t << "</mscfile>" << endl;
 }
 void XmlDocVisitor::visitPre(DocLink *lnk)
 {
@@ -932,6 +958,19 @@ void XmlDocVisitor::visitPost(DocText *)
 {
 }
 
+void XmlDocVisitor::visitPre(DocHtmlBlockQuote *)
+{
+  if (m_hide) return;
+  m_t << "<blockquote>";
+}
+
+void XmlDocVisitor::visitPost(DocHtmlBlockQuote *)
+{
+  if (m_hide) return;
+  m_t << "</blockquote>";
+}
+
+
 void XmlDocVisitor::filter(const char *str)
 { 
   m_t << convertToXML(str);
